@@ -33,6 +33,7 @@ Expert::Expert()
   m_treeWidget = new QTreeWidget;
   m_treeWidget->setColumnCount(1);
   m_topicStack = new QStackedWidget;
+  m_inShowHelp = FALSE;
 
   QFile file(SA(":/config.xml"));
   QString err;
@@ -158,7 +159,8 @@ QWidget *Expert::createTopicWidget(QDomElement &elem)
             child.attribute(SA("id")),
             child.attribute(SA("defval")),
             mode,
-            child.attribute(SA("docs"))
+            child.attribute(SA("docs")),
+            child.attribute(SA("abspath"))
            );
       m_options.insert(
           child.attribute(SA("id")),
@@ -320,9 +322,9 @@ void Expert::loadSettings(QSettings *s)
   {
     i.next();
     QVariant var = s->value(SA("config/")+i.key());
-    //printf("Loading key %s: type=%d\n",qPrintable(i.key()),var.type());
     if (i.value())
     {
+      //printf("Loading key %s: type=%d value='%s'\n",qPrintable(i.key()),var.type(),qPrintable(var.toString()));
       i.value()->value() = var;
       i.value()->update();
     }
@@ -335,9 +337,10 @@ void Expert::saveSettings(QSettings *s)
   while (i.hasNext()) 
   {
     i.next();
+    //printf("Saving key %s: type=%d value='%s'\n",qPrintable(i.key()),i.value()->value().type(),qPrintable(i.value()->value().toString()));
     if (i.value())
     {
-      s->value(SA("config/")+i.key(),i.value()->value());
+      s->setValue(SA("config/")+i.key(),i.value()->value());
     }
   }
 }
@@ -433,13 +436,18 @@ bool Expert::restoreInnerState ( const QByteArray & state )
 
 void Expert::showHelp(Input *option)
 {
-  m_helper->setText(
-           QString::fromAscii("<qt><b>")+option->id()+
-           QString::fromAscii("</b><br>")+
-           option->docs().
-           replace(QChar::fromAscii('\n'),QChar::fromAscii(' '))+
-           QString::fromAscii("<qt>")
-          );
+  if (!m_inShowHelp)
+  {
+    m_inShowHelp = TRUE;
+    m_helper->setText(
+        QString::fromAscii("<qt><b>")+option->id()+
+        QString::fromAscii("</b><br>")+
+        option->docs().
+        replace(QChar::fromAscii('\n'),QChar::fromAscii(' '))+
+        QString::fromAscii("<qt>")
+        );
+    m_inShowHelp = FALSE;
+  }
 }
 
 void Expert::nextTopic()
