@@ -3,7 +3,7 @@
  * 
  *
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,6 +18,13 @@
 
 #include "cmdmapper.h"
 
+/** Call representing a mapping from a command name to a command ID. */
+struct CommandMap
+{
+  const char *cmdName;
+  int cmdId;
+};
+
 CommandMap cmdMap[] =
 {
   { "a",             CMD_EMPHASIS },
@@ -75,6 +82,7 @@ CommandMap cmdMap[] =
   { "return",        CMD_RETURN },
   { "returns",       CMD_RETURN },
   { "retval",        CMD_RETVAL },
+  { "rtfonly",       CMD_RTFONLY },
   { "sa",            CMD_SA },
   { "secreflist",    CMD_SECREFLIST },
   { "section",       CMD_SECTION },
@@ -105,6 +113,7 @@ CommandMap cmdMap[] =
   { "$",             CMD_DOLLAR },
   { "#",             CMD_HASH },
   { "%",             CMD_PERCENT },
+  { "|",             CMD_PIPE },
   { "::",            CMD_DCOLON },
   { "\"",            CMD_QUOTE },
   { "_internalref",  CMD_INTERNALREF },
@@ -117,6 +126,8 @@ CommandMap cmdMap[] =
   { "includelineno", CMD_INCWITHLINES },
   { "inheritdoc",    CMD_INHERITDOC },
   { "mscfile",       CMD_MSCFILE },
+  { "rtfonly",       CMD_RTFONLY },
+  { "endrtfonly",    CMD_ENDRTFONLY },
   { 0,               0 },
 };
 
@@ -162,6 +173,7 @@ CommandMap htmlTagMap[] =
   { "h6",         HTML_H6 },
   { "span",       HTML_SPAN },
   { "div",        HTML_DIV },
+  { "blockquote", HTML_BLOCKQUOTE },
 
   { "c",            XML_C },
   // { "code",       XML_CODE },  <= ambiguous <code> is also a HTML tag
@@ -185,6 +197,7 @@ CommandMap htmlTagMap[] =
   { "summary",      XML_SUMMARY },
   { "term",         XML_TERM },
   { "value",        XML_VALUE },
+  { "inheritdoc",   XML_INHERITDOC },
   { 0,              0 }
 };
 
@@ -193,6 +206,25 @@ CommandMap htmlTagMap[] =
 Mapper *Mappers::cmdMapper     = new Mapper(cmdMap,TRUE);
 Mapper *Mappers::htmlTagMapper = new Mapper(htmlTagMap,FALSE);
 
+int Mapper::map(const char *n)
+{
+  QCString name=n;
+  if (!m_cs) name=name.lower();
+  int *result;
+  return !name.isEmpty() && (result=m_map.find(name)) ? *result: 0;
+}
+
+Mapper::Mapper(const CommandMap *cm,bool caseSensitive) : m_map(89), m_cs(caseSensitive)
+{
+  m_map.setAutoDelete(TRUE);
+  const CommandMap *p = cm;
+  while (p->cmdName)
+  {
+    m_map.insert(p->cmdName,new int(p->cmdId));
+    p++;
+  }
+}
+
 void Mappers::freeMappers()
 {
   delete cmdMapper;     cmdMapper     = 0;
