@@ -365,6 +365,9 @@
 "      <xsd:element name=\"center\" type=\"docMarkupType\" />\n"
 "      <xsd:element name=\"small\" type=\"docMarkupType\" />\n"
 "      <xsd:element name=\"htmlonly\" type=\"xsd:string\" />\n"
+"      <xsd:element name=\"manonly\" type=\"xsd:string\" />\n"
+"      <xsd:element name=\"xmlonly\" type=\"xsd:string\" />\n"
+"      <xsd:element name=\"rtfonly\" type=\"xsd:string\" />\n"
 "      <xsd:element name=\"latexonly\" type=\"xsd:string\" />\n"
 "      <xsd:element name=\"dot\" type=\"xsd:string\" />\n"
 "      <xsd:element name=\"anchor\" type=\"docAnchorType\" />\n"
@@ -389,6 +392,75 @@
 "      <xsd:element name=\"ring\" type=\"docCharType\" />\n"
 "      <xsd:element name=\"szlig\" type=\"docEmptyType\" />\n"
 "      <xsd:element name=\"nonbreakablespace\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"aelig\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"AElig\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"Gamma\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"Delta\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"Theta\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"Lambda\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"Xi\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"Pi\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"Sigma\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"Upsilon\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"Phi\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"Psi\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"Omega\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"alpha\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"beta\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"gamma\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"delta\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"epsilon\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"zeta\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"eta\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"theta\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"iota\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"kappa\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"lambda\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"mu\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"nu\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"xi\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"pi\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"rho\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"sigma\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"tau\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"upsilon\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"phi\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"chi\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"psi\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"omega\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"sigmaf\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"sect\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"deg\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"prime\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"Prime\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"infin\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"empty\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"plusmn\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"times\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"minus\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"sdot\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"part\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"nabla\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"radic\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"perp\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"sum\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"int\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"prod\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"sim\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"asymp\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"ne\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"equiv\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"prop\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"le\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"ge\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"larr\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"rarr\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"isin\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"notin\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"lceil\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"rceil\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"lfloor\" type=\"docEmptyType\" />\n"
+"      <xsd:element name=\"rfloor\" type=\"docEmptyType\" />\n"
 "    </xsd:choice>\n"
 "  </xsd:group>\n"
 "\n"
@@ -419,6 +491,7 @@
 "      <xsd:element name=\"parameterlist\" type=\"docParamListType\" />\n"
 "      <xsd:element name=\"xrefsect\" type=\"docXRefSectType\" />\n"
 "      <xsd:element name=\"copydoc\" type=\"docCopyType\" />\n"
+"      <xsd:element name=\"blockquote\" type=\"docBlockQuoteType\" />\n"
 "    </xsd:choice>\n"
 "  </xsd:group>\n"
 "\n"
@@ -612,6 +685,12 @@
 "    <xsd:attribute name=\"link\" type=\"xsd:string\" /> \n"
 "  </xsd:complexType>\n"
 "\n"
+"  <xsd:complexType name=\"docBlockQuoteType\">\n"
+"    <xsd:sequence>\n"
+"      <xsd:element name=\"para\" type=\"docParaType\" minOccurs=\"0\" maxOccurs=\"unbounded\" />\n"
+"    </xsd:sequence>\n"
+"  </xsd:complexType>\n"
+"\n"
 "  <xsd:complexType name=\"docCharType\">\n"
 "    <xsd:attribute name=\"char\" type=\"DoxCharRange\"/> \n"
 "  </xsd:complexType>\n"
@@ -815,6 +894,9 @@
 "      <xsd:enumeration value=\"retain\"/>\n"
 "      <xsd:enumeration value=\"copy\"/>\n"
 "      <xsd:enumeration value=\"assign\"/>\n"
+"      <xsd:enumeration value=\"weak\"/>\n"
+"      <xsd:enumeration value=\"strong\"/>\n"
+"      <xsd:enumeration value=\"unretained\"/>\n"
 "    </xsd:restriction>\n"
 "  </xsd:simpleType>\n"
 "\n"
