@@ -2,7 +2,7 @@
  *
  * $Id: index.cpp,v 1.30 1999/03/06 22:15:39 root Exp $
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -37,12 +37,15 @@
 #include "parserintf.h"
 #include "marshal.h"
 #include "debug.h"
+#include "vhdldocgen.h"
 
 #define START_MARKER 0x4445465B // DEF[
 #define END_MARKER   0x4445465D // DEF]
 
 //-----------------------------------------------------------------------------------------
 
+
+/** Private data associated with a Definition object. */
 class DefinitionImpl
 {
   public:
@@ -244,7 +247,7 @@ void Definition::addToMap(const char *name,Definition *d)
 
 void Definition::removeFromMap(Definition *d)
 {
-  QString symbolName = d->m_symbolName;
+  QCString symbolName = d->m_symbolName;
   if (!symbolName.isEmpty()) 
   {
     //printf("******* removing symbol `%s' (%p)\n",symbolName.data(),d);
@@ -319,10 +322,11 @@ void Definition::addSectionsToDefinition(QList<SectionInfo> *anchorList)
     //printf("Add section `%s' to definition `%s'\n",
     //    si->label.data(),name().data());
     SectionInfo *gsi=Doxygen::sectionDict.find(si->label);
+    //printf("===== label=%s gsi=%p\n",si->label.data(),gsi);
     if (gsi==0)
     {
       gsi = new SectionInfo(*si);
-      Doxygen::sectionDict.insert(si->label,gsi);
+      Doxygen::sectionDict.append(si->label,gsi);
     }
     if (m_impl->sectionDict==0) 
     {
@@ -330,20 +334,148 @@ void Definition::addSectionsToDefinition(QList<SectionInfo> *anchorList)
     }
     if (m_impl->sectionDict->find(gsi->label)==0)
     {
-      m_impl->sectionDict->insert(gsi->label,gsi);
+      m_impl->sectionDict->append(gsi->label,gsi);
       gsi->definition = this;
     }
     si=anchorList->next();
   }
 }
 
+bool Definition::hasSections() const
+{
+  makeResident();
+  //printf("Definition::hasSections(%s) #sections=%d\n",name().data(),
+  //    m_impl->sectionDict ? m_impl->sectionDict->count() : 0);
+  if (m_impl->sectionDict==0) return FALSE;
+  SDict<SectionInfo>::Iterator li(*m_impl->sectionDict);
+  SectionInfo *si;
+  for (li.toFirst();(si=li.current());++li)
+  {
+    if (si->type==SectionInfo::Section || 
+        si->type==SectionInfo::Subsection || 
+        si->type==SectionInfo::Subsubsection ||
+        si->type==SectionInfo::Paragraph)
+    {
+      return TRUE;
+    }
+  }
+  return FALSE;
+}
+
+void Definition::addSectionsToIndex()
+{
+  makeResident();
+  if (m_impl->sectionDict==0) return;
+  //printf("Definition::addSectionsToIndex()\n");
+  SDict<SectionInfo>::Iterator li(*m_impl->sectionDict);
+  SectionInfo *si;
+  int level=1;
+  for (li.toFirst();(si=li.current());++li)
+  {
+    if (si->type==SectionInfo::Section       || 
+        si->type==SectionInfo::Subsection    || 
+        si->type==SectionInfo::Subsubsection ||
+        si->type==SectionInfo::Paragraph)
+    {
+      //printf("  level=%d title=%s\n",level,si->title.data());
+      int nextLevel = (int)si->type;
+      int i;
+      if (nextLevel>level)
+      {
+        for (i=level;i<nextLevel;i++)
+        {
+          Doxygen::indexList.incContentsDepth();
+        }
+      }
+      else if (nextLevel<level)
+      {
+        for (i=nextLevel;i<level;i++)
+        {
+          Doxygen::indexList.decContentsDepth();
+        }
+      }
+      QCString title = si->title;
+      if (title.isEmpty()) title = si->label;
+      Doxygen::indexList.addContentsItem(TRUE,title,
+                                         getReference(),
+                                         getOutputFileBase(),
+                                         si->label,
+                                         FALSE,
+                                         TRUE);
+      level = nextLevel;
+    }
+  }
+  while (level>1)
+  {
+    Doxygen::indexList.decContentsDepth();
+    level--;
+  }
+}
+
+void Definition::writeToc(OutputList &ol)
+{
+  makeResident();
+  if (m_impl->sectionDict==0) return;
+  ol.pushGeneratorState();
+  ol.disableAllBut(OutputGenerator::Html);
+  ol.writeString("<div class=\"toc\">");
+  ol.writeString("<h3>");
+  ol.writeString(theTranslator->trRTFTableOfContents());
+  ol.writeString("</h3>\n");
+  ol.writeString("<ul>");
+  SDict<SectionInfo>::Iterator li(*m_impl->sectionDict);
+  SectionInfo *si;
+  int level=1;
+  char cs[2];
+  cs[1]='\0';
+  bool inLi[5]={ FALSE, FALSE, FALSE, FALSE };
+  for (li.toFirst();(si=li.current());++li)
+  {
+    if (si->type==SectionInfo::Section       || 
+        si->type==SectionInfo::Subsection    || 
+        si->type==SectionInfo::Subsubsection ||
+        si->type==SectionInfo::Paragraph)
+    {
+      //printf("  level=%d title=%s\n",level,si->title.data());
+      int nextLevel = (int)si->type;
+      if (nextLevel>level)
+      {
+        ol.writeString("<ul>");
+      }
+      else if (nextLevel<level)
+      {
+        if (inLi[level]) ol.writeString("</li>\n");
+        inLi[level]=FALSE;
+        ol.writeString("</ul>\n");
+      }
+      cs[0]='0'+nextLevel;
+      if (inLi[nextLevel]) ol.writeString("</li>\n");
+      ol.writeString("<li class=\"level"+QCString(cs)+"\"><a href=\"#"+si->label+"\">"+si->title+"</a>");
+      inLi[nextLevel]=TRUE;
+      level = nextLevel;
+    }
+  }
+  while (level>1)
+  {
+    if (inLi[level]) ol.writeString("</li>\n");
+    inLi[level]=FALSE;
+    ol.writeString("</ul>\n");
+    level--;
+  }
+  if (inLi[level]) ol.writeString("</li>\n");
+  inLi[level]=FALSE;
+  ol.writeString("</ul>\n");
+  ol.writeString("</div>\n");
+  ol.popGeneratorState();
+}
+
 void Definition::writeDocAnchorsToTagFile()
 {
   makeResident();
   if (!Config_getString("GENERATE_TAGFILE").isEmpty() && m_impl->sectionDict)
   {
     //printf("%s: writeDocAnchorsToTagFile(%d)\n",name().data(),m_sectionDict->count());
-    QDictIterator<SectionInfo> sdi(*m_impl->sectionDict);
+    SDict<SectionInfo>::Iterator sdi(*m_impl->sectionDict);
     SectionInfo *si;
     for (;(si=sdi.current());++sdi)
     {
@@ -382,12 +514,12 @@ bool Definition::_docsAlreadyAdded(const QCString &doc)
 void Definition::_setDocumentation(const char *d,const char *docFile,int docLine,
                                    bool stripWhiteSpace,bool atTop)
 {
+  //printf("%s::setDocumentation(%s,%s,%d,%d)\n",name().data(),d,docFile,docLine,stripWhiteSpace);
   if (d==0) return;
-  //printf("Definition::setDocumentation(%s,%s,%d,%d)\n",d,docFile,docLine,stripWhiteSpace);
   QCString doc = d;
   if (stripWhiteSpace)
   {
-    doc = stripLeadingAndTrailingEmptyLines(doc);
+    doc = stripLeadingAndTrailingEmptyLines(doc,docLine);
   }
   else // don't strip whitespace
   {
@@ -541,6 +673,7 @@ static bool readCodeFragment(const char *fileName,
                       int &startLine,int &endLine,QCString &result)
 {
   static bool filterSourceFiles = Config_getBool("FILTER_SOURCE_FILES");
+  static int tabSize = Config_getInt("TAB_SIZE");
   //printf("readCodeFragment(%s,%d,%d)\n",fileName,startLine,endLine);
   if (fileName==0 || fileName[0]==0) return FALSE; // not a valid file name
   QCString filter = getFileFilter(fileName,TRUE);
@@ -589,7 +722,7 @@ static bool readCodeFragment(const char *fileName,
           }
           else if (c=='\t') 
           {
-            col+=Config_getInt("TAB_SIZE") - (col%Config_getInt("TAB_SIZE"));
+            col+=tabSize - (col%tabSize);
           }
           else if (pc=='/' && c=='/') // skip single line comment
           {
@@ -615,7 +748,7 @@ static bool readCodeFragment(const char *fileName,
           cn=fgetc(f);
           if (cn!=':') found=TRUE;
         }
-        else if (c=='{')
+        else if (c=='{')   // } so vi matching brackets has no problem
         {
           found=TRUE;
         }
@@ -679,6 +812,8 @@ static bool readCodeFragment(const char *fileName,
     if (usePipe) 
     {
       portable_pclose(f); 
+      Debug::print(Debug::FilterOutput, 0, "Filter output\n");
+      Debug::print(Debug::FilterOutput,0,"-------------\n%s\n-------------\n",result.data());
     }
     else 
     {
@@ -864,6 +999,14 @@ void Definition::writeInlineCode(OutputList &ol,const char *scopeName)
       //printf("Read:\n`%s'\n\n",codeFragment.data());
       MemberDef *thisMd = 0;
       if (definitionType()==TypeMember) thisMd = (MemberDef *)this;
+
+      // vhdl  parser can' t start at an arbitrary point in the source code
+      if(this->getLanguage()==SrcLangExt_VHDL)
+      {
+        if (thisMd) VhdlDocGen::writeCodeFragment(ol,actualStart,codeFragment,thisMd);
+        return;
+      }
+
       ol.startCodeFragment();
       pIntf->parseCode(ol,               // codeOutIntf
                        scopeName,        // scope
@@ -1112,12 +1255,12 @@ void Definition::addInnerCompound(Definition *)
 
 QCString Definition::qualifiedName() const
 {
-  static int count=0;
-  count++;
+  //static int count=0;
+  //count++;
   makeResident();
   if (!m_impl->qualifiedName.isEmpty()) 
   {
-    count--;
+    //count--;
     return m_impl->qualifiedName;
   }
   
@@ -1126,12 +1269,12 @@ QCString Definition::qualifiedName() const
   {
     if (m_impl->localName=="<globalScope>") 
     {
-      count--;
+      //count--;
       return "";
     }
     else 
     {
-      count--;
+      //count--;
       return m_impl->localName; 
     }
   }
@@ -1142,10 +1285,12 @@ QCString Definition::qualifiedName() const
   }
   else
   {
-    m_impl->qualifiedName = m_impl->outerScope->qualifiedName()+"::"+m_impl->localName;
+    m_impl->qualifiedName = m_impl->outerScope->qualifiedName()+
+           getLanguageSpecificSeparator(getLanguage())+
+           m_impl->localName;
   }
   //printf("end %s::qualifiedName()=%s\n",name().data(),m_impl->qualifiedName.data());
-  count--;
+  //count--;
   return m_impl->qualifiedName;
 };
 
@@ -1288,23 +1433,33 @@ QCString Definition::pathFragment() const
   return result;
 }
 
-void Definition::writePathFragment(OutputList &ol) const
+/*! Returns the string used in the footer for $navpath when 
+ *  GENERATE_TREEVIEW is enabled
+ */
+QCString Definition::navigationPathAsString() const
 {
   makeResident();
+  QCString result;
   if (m_impl->outerScope && m_impl->outerScope!=Doxygen::globalScope)
   {
-    m_impl->outerScope->writePathFragment(ol);
+    result+=m_impl->outerScope->navigationPathAsString();
   }
-  ol.writeString("      <li class=\"navelem\">");
+  else if (definitionType()==Definition::TypeFile && ((const FileDef*)this)->getDirDef())
+  {
+    result+=((const FileDef*)this)->getDirDef()->navigationPathAsString();
+  }
+  result+="<li class=\"navelem\">";
   if (isLinkable())
   {
     if (definitionType()==Definition::TypeGroup && ((const GroupDef*)this)->groupTitle())
     {
-      ol.writeObjectLink(getReference(),getOutputFileBase(),0,((const GroupDef*)this)->groupTitle());
+      result+="<a class=\"el\" href=\"$relpath$"+getOutputFileBase()+Doxygen::htmlFileExtension+"\">"+
+              ((const GroupDef*)this)->groupTitle()+"</a>";
     }
     else if (definitionType()==Definition::TypePage && !((const PageDef*)this)->title().isEmpty())
     {
-      ol.writeObjectLink(getReference(),getOutputFileBase(),0,((const PageDef*)this)->title());
+      result+="<a class=\"el\" href=\"$relpath$"+getOutputFileBase()+Doxygen::htmlFileExtension+"\">"+
+              ((const PageDef*)this)->title()+"</a>";
     }
     else if (definitionType()==Definition::TypeClass)
     {
@@ -1313,46 +1468,36 @@ void Definition::writePathFragment(OutputList &ol) const
       {
         name = name.left(name.length()-2);
       }
-      ol.writeObjectLink(getReference(),getOutputFileBase(),0,name);
+      result+="<a class=\"el\" href=\"$relpath$"+getOutputFileBase()+Doxygen::htmlFileExtension;
+      if (!anchor().isEmpty()) result+="#"+anchor();
+      result+="\">"+name+"</a>";
     }
     else
     {
-      ol.writeObjectLink(getReference(),getOutputFileBase(),0,m_impl->localName);
+      result+="<a class=\"el\" href=\"$relpath$"+getOutputFileBase()+Doxygen::htmlFileExtension+"\">"+
+              m_impl->localName+"</a>";
     }
   }
   else
   {
-    ol.startBold();
-    ol.docify(m_impl->localName);
-    ol.endBold();
+    result+="<b>"+m_impl->localName+"</b>";
   }
-  ol.writeString("      </li>\n");
+  result+="</li>";
+  return result;
 }
 
-void Definition::writeNavigationPath(OutputList &ol,bool showSearchInfo) const
+void Definition::writeNavigationPath(OutputList &ol) const
 {
-  static bool generateTreeView = Config_getBool("GENERATE_TREEVIEW");
-
   ol.pushGeneratorState();
   ol.disableAllBut(OutputGenerator::Html);
 
-  if (generateTreeView)
-  {
-    ol.writeString("</div>\n");
-  }
-  if (showSearchInfo)
-  {
-    ol.writeSearchInfo();
-  }
-
-  ol.writeString("  <div id=\"nav-path\" class=\"navpath\">\n");
-  ol.writeString("    <ul>\n");
-  writePathFragment(ol);
-  if (!generateTreeView)
-  {
-    ol.writeString("    </ul>\n");
-    ol.writeString("  </div>\n");
-  }
+  QCString navPath;
+  navPath += "<div id=\"nav-path\" class=\"navpath\">\n"
+             "  <ul>\n";
+  navPath += navigationPathAsString();
+  navPath += "  </ul>\n"
+             "</div>\n";
+  ol.writeNavigationPath(navPath);
 
   ol.popGeneratorState();
 }
@@ -1382,12 +1527,63 @@ QCString Definition::docFile() const
   return m_impl->details ? m_impl->details->file : QCString("<"+m_name+">"); 
 }
 
+//----------------------------------------------------------------------------
+// strips w from s iff s starts with w
+static bool stripWord(QCString &s,QCString w)
+{
+  bool success=FALSE;
+  if (s.left(w.length())==w) 
+  {
+    success=TRUE;
+    s=s.right(s.length()-w.length());
+  }
+  return success;
+}
+
+//----------------------------------------------------------------------------
+// some quasi intelligent brief description abbreviator :^)
+QCString abbreviate(const char *s,const char *name)
+{
+  QCString scopelessName=name;
+  int i=scopelessName.findRev("::");
+  if (i!=-1) scopelessName=scopelessName.mid(i+2);
+  QCString result=s;
+  result=result.stripWhiteSpace();
+  // strip trailing .
+  if (!result.isEmpty() && result.at(result.length()-1)=='.') 
+    result=result.left(result.length()-1);
+
+  // strip any predefined prefix
+  QStrList &briefDescAbbrev = Config_getList("ABBREVIATE_BRIEF");
+  const char *p = briefDescAbbrev.first();
+  while (p)
+  {
+    QCString s = p;
+    s.replace(QRegExp("\\$name"), scopelessName);  // replace $name with entity name
+    s += " ";
+    stripWord(result,s);
+    p = briefDescAbbrev.next();
+  }
+
+  // capitalize first word
+  if (!result.isEmpty())
+  {
+    int c=result[0];
+    if (c>='a' && c<='z') c+='A'-'a';
+    result[0]=c;
+  }
+  return result;
+}
+
+
 //----------------------
 
-QCString Definition::briefDescription() const 
+QCString Definition::briefDescription(bool abbr) const 
 { 
   makeResident();
-  return m_impl->brief ? m_impl->brief->doc : QCString(""); 
+  return m_impl->brief ? 
+         (abbr ? abbreviate(m_impl->brief->doc,displayName()) : m_impl->brief->doc) :
+         QCString(""); 
 }
 
 QCString Definition::briefDescriptionAsTooltip() const
