@@ -22,6 +22,7 @@ DirDef::DirDef(const char *path) : Definition(path,1,path)
   m_dispName = stripFromPath(path);
   // get short name (last part of path)
   m_shortName = path;
+  m_diskName = path;
   if (m_shortName.at(m_shortName.length()-1)=='/')
   { // strip trailing /
     m_shortName = m_shortName.left(m_shortName.length()-1);
@@ -49,7 +50,7 @@ DirDef::~DirDef()
 
 bool DirDef::isLinkableInProject() const 
 { 
-  return !isReference() && Config_getBool("SHOW_DIRECTORIES"); 
+  return !isReference(); 
 }
 
 bool DirDef::isLinkable() const 
@@ -105,8 +106,9 @@ static QCString encodeDirName(const QCString &anchor)
 
 QCString DirDef::getOutputFileBase() const
 {
-  return "dir_"+encodeDirName(name());
-  //return QCString().sprintf("dir_%06d",m_dirCount);
+  //printf("DirDef::getOutputFileBase() %s->dir_%s\n",
+  //    m_diskName.data(),encodeDirName(m_diskName).data());
+  return "dir_"+encodeDirName(m_diskName);
 }
 
 void DirDef::writeDetailedDescription(OutputList &ol,const QCString &title)
@@ -114,9 +116,12 @@ void DirDef::writeDetailedDescription(OutputList &ol,const QCString &title)
   if ((!briefDescription().isEmpty() && Config_getBool("REPEAT_BRIEF")) || 
       !documentation().isEmpty())
   {
-    ol.writeRuler();
     ol.pushGeneratorState();
-    ol.disableAllBut(OutputGenerator::Html);
+      ol.disable(OutputGenerator::Html);
+      ol.writeRuler();
+    ol.popGeneratorState();
+    ol.pushGeneratorState();
+      ol.disableAllBut(OutputGenerator::Html);
       ol.writeAnchor(0,"details");
     ol.popGeneratorState();
     ol.startGroupHeader();
@@ -213,7 +218,7 @@ void DirDef::writeSubDirList(OutputList &ol)
     DirDef *dd=m_subdirs.first();
     while (dd)
     {
-      ol.startMemberItem(0);
+      ol.startMemberItem(dd->getOutputFileBase(),0);
       ol.parseText(theTranslator->trDir(FALSE,TRUE)+" ");
       ol.insertMemberAlign();
       ol.writeObjectLink(dd->getReference(),dd->getOutputFileBase(),0,dd->shortName());
@@ -224,12 +229,12 @@ void DirDef::writeSubDirList(OutputList &ol)
       }
       if (!dd->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
       {
-        ol.startMemberDescription();
+        ol.startMemberDescription(dd->getOutputFileBase());
         ol.parseDoc(briefFile(),briefLine(),dd,0,dd->briefDescription(),
             FALSE, // indexWords
             FALSE, // isExample
             0,     // exampleName
-            FALSE, // single line
+            TRUE,  // single line
             TRUE   // link from index
            );
         ol.endMemberDescription();
@@ -253,7 +258,7 @@ void DirDef::writeFileList(OutputList &ol)
     FileDef *fd=m_fileList->first();
     while (fd)
     {
-      ol.startMemberItem(0);
+      ol.startMemberItem(fd->getOutputFileBase(),0);
       ol.docify(theTranslator->trFile(FALSE,TRUE)+" ");
       ol.insertMemberAlign();
       if (fd->isLinkable())
@@ -285,12 +290,12 @@ void DirDef::writeFileList(OutputList &ol)
       ol.endMemberItem();
       if (!fd->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
       {
-        ol.startMemberDescription();
+        ol.startMemberDescription(fd->getOutputFileBase());
         ol.parseDoc(briefFile(),briefLine(),fd,0,fd->briefDescription(),
             FALSE, // indexWords
             FALSE, // isExample
             0,     // exampleName
-            FALSE, // single line
+            TRUE,  // single line
             TRUE   // link from index
            );
         ol.endMemberDescription();
@@ -737,6 +742,86 @@ void DirRelation::writeDocumentation(OutputList &ol)
 //----------------------------------------------------------------------
 // external functions
 
+/** In order to create stable, but unique directory names,
+ *  we compute the common part of the path shared by all directories.
+ */
+static void computeCommonDirPrefix()
+{
+  QCString path;
+  DirDef *dir;
+  DirSDict::Iterator sdi(*Doxygen::directories);
+  if (Doxygen::directories->count()>0) // we have at least one dir
+  {
+    // start will full path of first dir
+    sdi.toFirst();
+    dir=sdi.current();
+    path=dir->name();
+    int i=path.findRev('/',path.length()-2);
+    path=path.left(i+1);
+    bool done=FALSE;
+    if (i==-1) 
+    {
+      path="";
+    }
+    else
+    {
+      while (!done)
+      {
+        int l = path.length();
+        int count=0;
+        for (sdi.toFirst();(dir=sdi.current());++sdi)
+        {
+          QCString dirName = dir->name();
+          if (dirName.length()>path.length())
+          {
+            if (strncmp(dirName,path,l)!=0) // dirName does not start with path
+            {
+              int i=path.findRev('/',l-2);
+              if (i==-1) // no unique prefix -> stop
+              {
+                path="";
+                done=TRUE;
+              }
+              else // restart with shorter path
+              {
+                path=path.left(i+1);
+                break;
+              }
+            }
+          }
+          else // dir is shorter than path -> take path of dir as new start
+          {
+            path=dir->name();
+            int i=path.findRev('/',l-2);
+            if (i==-1) // no unique prefix -> stop
+            {
+              path="";
+              done=TRUE;
+            }
+            else // restart with shorter path
+            {
+              path=path.left(i+1);
+            }
+            break;
+          }
+          count++;
+        }
+        if (count==Doxygen::directories->count())
+          // path matches for all directories -> found the common prefix
+        {
+          done=TRUE;
+        }
+      }
+    }
+  }
+  for (sdi.toFirst();(dir=sdi.current());++sdi)
+  {
+    QCString diskName = dir->name().right(dir->name().length()-path.length());
+    dir->setDiskName(diskName);
+    //printf("set disk name: %s -> %s\n",dir->name().data(),diskName.data());
+  }
+}
+
 void buildDirectories()
 {
   // for each input file
@@ -786,6 +871,7 @@ void buildDirectories()
       }
     }
   }
+  computeCommonDirPrefix();
 }
 
 void computeDirDependencies()
@@ -804,80 +890,8 @@ void computeDirDependencies()
     dir->computeDependencies();
   }
 
-#if 0
-  printf("-------------------------------------------------------------\n");
-  // print dependencies (for debugging)
-  for (sdi.toFirst();(dir=sdi.current());++sdi)
-  {
-    if (dir->usedDirs())
-    {
-      QDictIterator<UsedDir> udi(*dir->usedDirs());
-      UsedDir *usedDir;
-      for (udi.toFirst();(usedDir=udi.current());++udi)
-      {
-        printf("%s depends on %s due to ",
-            dir->shortName().data(),usedDir->dir()->shortName().data());
-        QDictIterator<FileDef> fdi(usedDir->files());
-        FileDef *fd;
-        for (fdi.toFirst();(fd=fdi.current());++fdi)
-        {
-          printf("%s ",fd->name().data());
-        }
-        printf("\n");
-      }
-    }
-  }
-  printf("^-^-^-^-^-^-^-^-^-^-^-^-^-^-^-^-^-^-^-^-^-^-^-^-^-^-^-^-^-^-^\n");
-#endif
 }
 
-#if 0
-void writeDirDependencyGraph(const char *dirName)
-{
-  QString path;
-  DirDef *dir;
-  DirSDict::Iterator sdi(*Doxygen::directories);
-  QFile htmlPage(QCString(dirName)+"/dirdeps.html");
-  if (htmlPage.open(IO_WriteOnly))
-  {
-    QTextStream out(&htmlPage);
-    out << "<html><body>";
-    for (sdi.toFirst();(dir=sdi.current());++sdi)
-    {
-      path=dirName;
-      path+="/";
-      path+=dir->getOutputFileBase();
-      path+="_dep.dot";
-      out << "<h4>" << dir->displayName() << "</h4>" << endl;
-      out << "<img src=\"" << dir->getOutputFileBase() << "_dep.gif\">" << endl;
-      QFile f(path);
-      if (f.open(IO_WriteOnly))
-      {
-        QTextStream t(&f);
-        dir->writeDepGraph(t);
-      }
-      f.close();
-
-      QCString imgExt = Config_getEnum("DOT_IMAGE_FORMAT");
-      QCString outFile = QCString(dirName)+"/"+
-                         dir->getOutputFileBase()+"_dep."+imgExt; 
-      DotRunner dotRun(path);
-      dotRun.addJob(imgExt,outFile);
-      dotRun.run();
-      
-      //QCString dotArgs(4096);
-      //dotArgs.sprintf("%s -Tgif -o %s",path.data(),outFile.data());
-      //if (portable_system(Config_getString("DOT_PATH")+"dot",dotArgs,FALSE)!=0)
-      //{
-      //  err("Problems running dot. Check your installation!\n");
-      //}
-    }
-    out << "</body></html>";
-  }
-  htmlPage.close();
-}
-#endif
-
 void generateDirDocs(OutputList &ol)
 {
   DirDef *dir;
