@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -13,12 +13,11 @@
  *
  */
 
+#include <qfile.h>
 #include "docsets.h"
 #include "config.h"
 #include "message.h"
 #include "doxygen.h"
-#include <qfile.h>
-
 
 DocSets::DocSets() : m_nodes(17), m_scopes(17)
 {
@@ -48,6 +47,8 @@ void DocSets::initialize()
   if (publisherId.isEmpty()) publisherId="PublisherId";
   QCString publisherName = Config_getString("DOCSET_PUBLISHER_NAME");
   if (publisherName.isEmpty()) publisherName="PublisherName";
+  QCString projectNumber = Config_getString("PROJECT_NUMBER");
+  if (projectNumber.isEmpty()) projectNumber="ProjectNumber";
 
   // -- write Makefile
   {
@@ -116,7 +117,9 @@ void DocSets::initialize()
         "     <key>CFBundleName</key>\n" 
         "     <string>" << projectName << "</string>\n" 
         "     <key>CFBundleIdentifier</key>\n"
-        "     <string>" << bundleId << ".docset</string>\n" 
+        "     <string>" << bundleId << "</string>\n" 
+        "     <key>CFBundleVersion</key>\n"
+        "     <string>" << projectNumber << "</string>\n"
         "     <key>DocSetFeedName</key>\n" 
         "     <string>" << feedName << "</string>\n"
         "     <key>DocSetPublisherIdentifier</key>\n"
@@ -163,7 +166,10 @@ void DocSets::initialize()
 
 void DocSets::finalize()
 {
-  m_nts << indent() << " </Node>" << endl;
+  if (!m_firstNode.at(m_dc-1))
+  {
+    m_nts << indent() << " </Node>" << endl;
+  }
   m_dc--;
   m_nts << "      </Subnodes>" << endl;
   m_nts << "    </Node>" << endl;
@@ -213,7 +219,8 @@ void DocSets::addContentsItem(bool isDir,
                               const char *file,
                               const char *anchor,
                               bool /* separateIndex */,
-                              bool /* addToNavIndex */)
+                              bool /* addToNavIndex */,
+                              Definition * /*def*/)
 {
   (void)isDir;
   if (file && ref==0)
@@ -225,7 +232,9 @@ void DocSets::addContentsItem(bool isDir,
     m_firstNode.at(m_dc-1)=FALSE;
     m_nts << indent() << " <Node>" << endl;
     m_nts << indent() << "  <Name>" << convertToXML(name) << "</Name>" << endl;
-    m_nts << indent() << "  <Path>" << file << Doxygen::htmlFileExtension << "</Path>" << endl;
+    m_nts << indent() << "  <Path>";
+    m_nts << file << Doxygen::htmlFileExtension;
+    m_nts << "</Path>" << endl;
     if (anchor)
     {
       m_nts << indent() << "  <Anchor>" << anchor << "</Anchor>" << endl;
@@ -290,7 +299,8 @@ void DocSets::addIndexItem(Definition *context,MemberDef *md,const char *)
     case SrcLangExt_VHDL:    lang="vhdl"; break;       // VHDL
     case SrcLangExt_XML:     lang="xml"; break;        // DBUS XML
     case SrcLangExt_Tcl:     lang="tcl"; break;        // Tcl
-    case SrcLangExt_Unknown: lang="unknown"; break;   // should not happen!
+    case SrcLangExt_Markdown:lang="markdown"; break;   // Markdown
+    case SrcLangExt_Unknown: lang="unknown"; break;    // should not happen!
   }
 
   if (md)
@@ -441,7 +451,7 @@ void DocSets::writeToken(FTextStream &t,
 {
   t << "  <Token>" << endl;
   t << "    <TokenIdentifier>" << endl;
-  QString name = d->name();
+  QCString name = d->name();
   if (name.right(2)=="-p")  name=name.left(name.length()-2);
   t << "      <Name>" << convertToXML(name) << "</Name>" << endl;
   if (!lang.isEmpty())
