@@ -2,7 +2,7 @@
  *
  * $Id: filedef.cpp,v 1.55 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -36,9 +36,11 @@
 #include "vhdldocgen.h"
 #include "debug.h"
 #include "layout.h"
+#include "entry.h"
 
 //---------------------------------------------------------------------------
 
+/** Class implementing CodeOutputInterface by throwing away everything. */
 class DevNullCodeDocInterface : public CodeOutputInterface
 {
   public:
@@ -48,7 +50,7 @@ class DevNullCodeDocInterface : public CodeOutputInterface
                                const char *) {}
     virtual void writeLineNumber(const char *,const char *,
                                  const char *,int) {}
-    virtual void startCodeLine() {}
+    virtual void startCodeLine(bool) {}
     virtual void endCodeLine() {}
     virtual void startCodeAnchor(const char *) {}
     virtual void endCodeAnchor() {}
@@ -169,9 +171,12 @@ void FileDef::writeDetailedDescription(OutputList &ol,const QCString &title)
       (Config_getBool("SOURCE_BROWSER") && getStartBodyLine()!=-1 && getBodyDef())
      )
   {
-    ol.writeRuler();
     ol.pushGeneratorState();
-    ol.disableAllBut(OutputGenerator::Html);
+      ol.disable(OutputGenerator::Html);
+      ol.writeRuler();
+    ol.popGeneratorState();
+    ol.pushGeneratorState();
+      ol.disableAllBut(OutputGenerator::Html);
       ol.writeAnchor(0,"details"); 
     ol.popGeneratorState();
     ol.startGroupHeader();
@@ -340,7 +345,11 @@ void FileDef::writeIncludeGraph(OutputList &ol)
   {
     //printf("Graph for file %s\n",name().data());
     DotInclDepGraph incDepGraph(this,FALSE);
-    if (!incDepGraph.isTrivial() && !incDepGraph.isTooBig())
+    if (incDepGraph.isTooBig())
+    {
+       err("warning: Include graph for '%s' not generated, too many nodes. Consider increasing DOT_GRAPH_MAX_NODES.\n",name().data());
+    }
+    else if (!incDepGraph.isTrivial())
     {
       ol.startTextBlock(); 
       ol.disable(OutputGenerator::Man);
@@ -360,7 +369,11 @@ void FileDef::writeIncludedByGraph(OutputList &ol)
   {
     //printf("Graph for file %s\n",name().data());
     DotInclDepGraph incDepGraph(this,TRUE);
-    if (!incDepGraph.isTrivial() && !incDepGraph.isTooBig())
+    if (incDepGraph.isTooBig())
+    {
+       err("warning: Included by graph for '%s' not generated, too many nodes. Consider increasing DOT_GRAPH_MAX_NODES.\n",name().data());
+    }
+    if (!incDepGraph.isTrivial())
     {
       ol.startTextBlock(); 
       ol.disable(OutputGenerator::Man);
@@ -482,7 +495,8 @@ void FileDef::writeSummaryLinks(OutputList &ol)
     {
       LayoutDocEntrySection *ls = (LayoutDocEntrySection*)lde;
       QCString label = lde->kind()==LayoutDocEntry::FileClasses ? "nested-classes" : "namespaces";
-      writeSummaryLink(ol,label,ls->title,first);
+      ol.writeSummaryLink(0,label,ls->title,first);
+      first=FALSE;
     }
     else if (lde->kind()==LayoutDocEntry::MemberDecl)
     {
@@ -490,7 +504,8 @@ void FileDef::writeSummaryLinks(OutputList &ol)
       MemberList * ml = getMemberList(lmd->type);
       if (ml && ml->declVisible())
       {
-        writeSummaryLink(ol,ml->listTypeAsString(),lmd->title,first);
+        ol.writeSummaryLink(0,ml->listTypeAsString(),lmd->title,first);
+        first=FALSE;
       }
     }
   }
@@ -525,7 +540,7 @@ void FileDef::writeDocumentation(OutputList &ol)
   QCString title = docname+versionTitle;
   QCString pageTitle=theTranslator->trFileReference(docname);
 
-  if (Config_getBool("SHOW_DIRECTORIES") && getDirDef())
+  if (getDirDef())
   {
     startFile(ol,getOutputFileBase(),name(),pageTitle,HLI_FileVisible,!generateTreeView);
     if (!generateTreeView)
@@ -784,10 +799,13 @@ void FileDef::writeSource(OutputList &ol)
   ol.disable(OutputGenerator::RTF);
   if (!latexSourceCode) ol.disable(OutputGenerator::Latex);
 
-  if (Config_getBool("SHOW_DIRECTORIES") && getDirDef())
+  bool isDocFile = isDocumentationFile();
+  bool genSourceFile = !isDocFile && generateSourceFile();
+  if (getDirDef())
   {
     startFile(ol,getSourceFileBase(),0,pageTitle,HLI_FileVisible,
-        !generateTreeView,getOutputFileBase());
+        !generateTreeView,
+        !isDocFile && genSourceFile ? 0 : getOutputFileBase());
     if (!generateTreeView)
     {
       getDirDef()->writeNavigationPath(ol);
@@ -799,8 +817,8 @@ void FileDef::writeSource(OutputList &ol)
   }
   else
   {
-    startFile(ol,getSourceFileBase(),0,pageTitle,HLI_FileVisible,
-        FALSE,getOutputFileBase());
+    startFile(ol,getSourceFileBase(),0,pageTitle,HLI_FileVisible,FALSE,
+        !isDocFile && genSourceFile ? 0 : getOutputFileBase());
     startTitle(ol,getSourceFileBase());
     ol.parseText(title);
     endTitle(ol,getSourceFileBase(),0);
@@ -1158,7 +1176,8 @@ bool FileDef::generateSourceFile() const
          (Config_getBool("SOURCE_BROWSER") || 
            (Config_getBool("VERBATIM_HEADERS") && guessSection(name())==Entry::HEADER_SEC) 
          ) &&
-         extension!=".doc" && extension!=".txt" && extension!=".dox"; 
+         extension!=".doc" && extension!=".txt" && extension!=".dox" &&
+         extension!=".md" && extension!=".markdown";  
 }
 
 
@@ -1484,7 +1503,9 @@ bool FileDef::isDocumentationFile() const
 {
   return name().right(4)==".doc" ||
          name().right(4)==".txt" ||
-         name().right(4)==".dox";
+         name().right(4)==".dox" ||
+         name().right(3)==".md"  ||
+         name().right(9)==".markdown";
 }
 
 void FileDef::acquireFileVersion()
