@@ -1,6 +1,6 @@
 /******************************************************************************
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -30,10 +30,11 @@
 #include "index.h"
 
 class QFile;
+class Definition;
 struct FTVNode;
 class FTextStream;
 
-/*! A class that generates a dynamic tree view side panel.
+/** A class that generates a dynamic tree view side panel.
  */
 class FTVHelp : public IndexIntf
 {
@@ -49,11 +50,9 @@ class FTVHelp : public IndexIntf
                          const char *ref,
                          const char *file,
                          const char *anchor,
-                         bool separateIndex=FALSE,
-                         bool addToNavIndex=FALSE);
-    //void addIndexItem(const char *, const char *, 
-    //                  const char *, const char *,
-    //                  const char *, const MemberDef *) {}
+                         bool separateIndex,
+                         bool addToNavIndex,
+                         Definition *def);
     void addIndexItem(Definition *,MemberDef *,const char *) {}
     void addIndexFile(const char *) {}
     void addImageFile(const char *) {}
@@ -63,13 +62,13 @@ class FTVHelp : public IndexIntf
     static void generateTreeViewImages();
     void generateTreeViewScripts();
   private:
-    void generateScript(FTextStream &t);
-    void generateTree(FTextStream &t,const QList<FTVNode> &nl,int level);
-    bool generateJSTree(FTextStream &tidx,FTextStream &t,const QList<FTVNode> &nl,int level,bool &first);
+    void generateTree(FTextStream &t,const QList<FTVNode> &nl,int level,int maxLevel,int &index);
+    //bool generateJSTree(FTextStream &tidx,FTextStream &t,const QList<FTVNode> &nl,int level,bool &first);
     //bool generateJSTreeTopLevel(FTextStream &tidx,FTextStream &t,const QList<FTVNode> &nl,int level,bool &first);
-    void generateIndent(FTextStream &t,FTVNode *n,int level);
+    QCString generateIndentLabel(FTVNode *n,int level);
+    void generateIndent(FTextStream &t,FTVNode *n,int level,bool opened);
     void generateLink(FTextStream &t,FTVNode *n);
-    void generateJSLink(FTextStream &t,FTVNode *n);
+    //void generateJSLink(FTextStream &t,FTVNode *n);
     QList<FTVNode> *m_indentNodes;
     int m_indent;
     bool m_topLevelIndex;
