@@ -2,7 +2,7 @@
  *
  * $Id: groupdef.cpp,v 1.29 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -36,6 +36,8 @@
 #include "dot.h"
 #include "vhdldocgen.h"
 #include "layout.h"
+#include "arguments.h"
+#include "entry.h"
 
 //---------------------------------------------------------------------------
 
@@ -545,9 +547,12 @@ void GroupDef::writeDetailedDescription(OutputList &ol,const QCString &title)
   {
     if (pageDict->count()!=countMembers()) // not only pages -> classical layout
     {
-      ol.writeRuler();
       ol.pushGeneratorState();
-      ol.disableAllBut(OutputGenerator::Html);
+        ol.disable(OutputGenerator::Html);
+        ol.writeRuler();
+      ol.popGeneratorState();
+      ol.pushGeneratorState();
+        ol.disableAllBut(OutputGenerator::Html);
         ol.writeAnchor(0,"details");
       ol.popGeneratorState();
       ol.startGroupHeader();
@@ -646,7 +651,7 @@ void GroupDef::writeFiles(OutputList &ol,const QCString &title)
     FileDef *fd=fileList->first();
     while (fd)
     {
-      ol.startMemberItem(0);
+      ol.startMemberItem(fd->getOutputFileBase(),0);
       ol.docify(theTranslator->trFile(FALSE,TRUE)+" ");
       ol.insertMemberAlign();
       ol.writeObjectLink(fd->getReference(),fd->getOutputFileBase(),0,fd->name());
@@ -657,8 +662,8 @@ void GroupDef::writeFiles(OutputList &ol,const QCString &title)
       ol.endMemberItem();
       if (!fd->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
       {
-        ol.startMemberDescription();
-        ol.parseDoc(briefFile(),briefLine(),fd,0,fd->briefDescription(),FALSE,FALSE);
+        ol.startMemberDescription(fd->getOutputFileBase());
+        ol.parseDoc(briefFile(),briefLine(),fd,0,fd->briefDescription(),FALSE,FALSE,0,TRUE,FALSE);
         ol.endMemberDescription();
       }
       fd=fileList->next();
@@ -676,30 +681,47 @@ void GroupDef::writeNamespaces(OutputList &ol,const QCString &title)
 void GroupDef::writeNestedGroups(OutputList &ol,const QCString &title)
 {
   // write list of groups
+  int count=0;
   if (groupList->count()>0)
+  {
+    GroupDef *gd=groupList->first();
+    while (gd)
+    {
+      if (gd->isVisible()) count++;
+      gd=groupList->next();
+    }
+  }
+  if (count>0)
   {
     ol.startMemberHeader("groups");
     ol.parseText(title);
     ol.endMemberHeader();
     ol.startMemberList();
+    if (Config_getBool("SORT_GROUP_NAMES"))
+    {
+      groupList->sort();
+    }
     GroupDef *gd=groupList->first();
     while (gd)
     {
-      ol.startMemberItem(0);
-      //ol.docify(theTranslator->trGroup(FALSE,TRUE));
-      //ol.docify(" ");
-      ol.insertMemberAlign();
-      ol.writeObjectLink(gd->getReference(),gd->getOutputFileBase(),0,gd->groupTitle());
-      if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
+      if (gd->isVisible())
       {
-        Doxygen::tagFile << "    <subgroup>" << convertToXML(gd->name()) << "</subgroup>" << endl;
-      }
-      ol.endMemberItem();
-      if (!gd->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
-      {
-        ol.startMemberDescription();
-        ol.parseDoc(briefFile(),briefLine(),gd,0,gd->briefDescription(),FALSE,FALSE);
-        ol.endMemberDescription();
+        ol.startMemberItem(gd->getOutputFileBase(),0);
+        //ol.docify(theTranslator->trGroup(FALSE,TRUE));
+        //ol.docify(" ");
+        ol.insertMemberAlign();
+        ol.writeObjectLink(gd->getReference(),gd->getOutputFileBase(),0,gd->groupTitle());
+        if (!Config_getString("GENERATE_TAGFILE").isEmpty()) 
+        {
+          Doxygen::tagFile << "    <subgroup>" << convertToXML(gd->name()) << "</subgroup>" << endl;
+        }
+        ol.endMemberItem();
+        if (!gd->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
+        {
+          ol.startMemberDescription(gd->getOutputFileBase());
+          ol.parseDoc(briefFile(),briefLine(),gd,0,gd->briefDescription(),FALSE,FALSE,0,TRUE,FALSE);
+          ol.endMemberDescription();
+        }
       }
       gd=groupList->next();
     }
@@ -719,7 +741,7 @@ void GroupDef::writeDirs(OutputList &ol,const QCString &title)
     DirDef *dd=dirList->first();
     while (dd)
     {
-      ol.startMemberItem(0);
+      ol.startMemberItem(dd->getOutputFileBase(),0);
       ol.parseText(theTranslator->trDir(FALSE,TRUE));
       ol.insertMemberAlign();
       ol.writeObjectLink(dd->getReference(),dd->getOutputFileBase(),0,dd->shortName());
@@ -730,8 +752,8 @@ void GroupDef::writeDirs(OutputList &ol,const QCString &title)
       }
       if (!dd->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
       {
-        ol.startMemberDescription();
-        ol.parseDoc(briefFile(),briefLine(),dd,0,dd->briefDescription(),FALSE,FALSE);
+        ol.startMemberDescription(dd->getOutputFileBase());
+        ol.parseDoc(briefFile(),briefLine(),dd,0,dd->briefDescription(),FALSE,FALSE,0,TRUE,FALSE);
         ol.endMemberDescription();
       }
       dd=dirList->next();
@@ -776,7 +798,7 @@ void GroupDef::writePageDocumentation(OutputList &ol)
         ol.endSection(si->label,SectionInfo::Subsection);
       }
       ol.startTextBlock();
-      ol.parseDoc(pd->docFile(),pd->docLine(),pd,0,pd->documentation()+pd->inbodyDocumentation(),TRUE,FALSE);
+      ol.parseDoc(pd->docFile(),pd->docLine(),pd,0,pd->documentation()+pd->inbodyDocumentation(),TRUE,FALSE,0,TRUE,FALSE);
       ol.endTextBlock();
     }
   }
@@ -864,7 +886,8 @@ void GroupDef::writeSummaryLinks(OutputList &ol)
                        lde->kind()==LayoutDocEntry::GroupFiles        ? "files"          :
                        lde->kind()==LayoutDocEntry::GroupNestedGroups ? "groups"         :
                        "dirs";
-      writeSummaryLink(ol,label,ls->title,first);
+      ol.writeSummaryLink(0,label,ls->title,first);
+      first=FALSE;
     }
     else if (lde->kind()==LayoutDocEntry::MemberDecl)
     {
@@ -872,7 +895,8 @@ void GroupDef::writeSummaryLinks(OutputList &ol)
       MemberList * ml = getMemberList(lmd->type);
       if (ml && ml->declVisible())
       {
-        writeSummaryLink(ol,ml->listTypeAsString(),lmd->title,first);
+        ol.writeSummaryLink(0,ml->listTypeAsString(),lmd->title,first);
+        first=FALSE;
       }
     }
   }
@@ -1443,3 +1467,18 @@ void GroupDef::removeMemberFromList(MemberList::ListType lt,MemberDef *md)
     if (ml) ml->remove(md); 
 }
 
+void GroupDef::sortSubGroups() 
+{ 
+    groupList->sort(); 
+}
+
+bool GroupDef::isLinkableInProject() const
+{
+  return !isReference() && isLinkable();
+}
+
+bool GroupDef::isLinkable() const
+{
+  return hasUserDocumentation();
+}
+
