@@ -2,7 +2,7 @@
  *
  * $Id: index.h,v 1.28 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -38,7 +38,7 @@ class IndexIntf
     virtual void decContentsDepth() = 0;
     virtual void addContentsItem(bool isDir, const char *name, const char *ref, 
                                  const char *file, const char *anchor, bool separateIndex,
-                                 bool addToNavIndex) = 0;
+                                 bool addToNavIndex,Definition *def) = 0;
     virtual void addIndexItem(Definition *context,MemberDef *md,const char *title) = 0;
     virtual void addIndexFile(const char *name) = 0;
     virtual void addImageFile(const char *name) = 0;
@@ -98,19 +98,32 @@ class IndexList : public IndexIntf
       for (li.toFirst();li.current();++li) (li.current()->*methodPtr)(a1,a2,a3,a4,a5,a6);
     }
 
-    template<typename A1,typename A2,typename A3,typename A4,typename A5,typename A6,typename A7>
-    void foreach(void (IndexIntf::*methodPtr)(A1,A2,A3,A4,A5,A6,A7),A1 a1,A2 a2,A3 a3,A4 a4,A5 a5,A6 a6,A7 a7)
+    template<typename A1,typename A2,typename A3,typename A4,typename A5,typename A6,typename A7,typename A8>
+    void foreach(void (IndexIntf::*methodPtr)(A1,A2,A3,A4,A5,A6,A7,A8),A1 a1,A2 a2,A3 a3,A4 a4,A5 a5,A6 a6,A7 a7,A8 a8)
     {
       QListIterator<IndexIntf> li(m_intfs);
-      for (li.toFirst();li.current();++li) (li.current()->*methodPtr)(a1,a2,a3,a4,a5,a6,a7);
+      for (li.toFirst();li.current();++li) (li.current()->*methodPtr)(a1,a2,a3,a4,a5,a6,a7,a8);
+    }
+
+    template<typename A1,typename A2,typename A3,typename A4,typename A5,typename A6,typename A7,typename A8,typename A9>
+    void foreach(void (IndexIntf::*methodPtr)(A1,A2,A3,A4,A5,A6,A7,A8,A9),A1 a1,A2 a2,A3 a3,A4 a4,A5 a5,A6 a6,A7 a7,A8 a8,A9 a9)
+    {
+      QListIterator<IndexIntf> li(m_intfs);
+      for (li.toFirst();li.current();++li) (li.current()->*methodPtr)(a1,a2,a3,a4,a5,a6,a7,a8,a9);
     }
 
   public:
     /** Creates a list of indexes */
-    IndexList() { m_intfs.setAutoDelete(TRUE); }
+    IndexList() { m_intfs.setAutoDelete(TRUE); m_enabled=TRUE; }
     /** Add an index generator to the list */
     void addIndex(IndexIntf *intf) 
     { m_intfs.append(intf); }
+    void disable()
+    { m_enabled = FALSE; }
+    void enable()
+    { m_enabled = TRUE; }
+    bool isEnabled() const
+    { return m_enabled; }
 
     // IndexIntf implementation
     void initialize() 
@@ -118,23 +131,26 @@ class IndexList : public IndexIntf
     void finalize() 
     { foreach(&IndexIntf::finalize); }
     void incContentsDepth()
-    { foreach(&IndexIntf::incContentsDepth); }
+    { if (m_enabled) foreach(&IndexIntf::incContentsDepth); }
     void decContentsDepth()
-    { foreach(&IndexIntf::decContentsDepth); }
+    { if (m_enabled) foreach(&IndexIntf::decContentsDepth); }
     void addContentsItem(bool isDir, const char *name, const char *ref, 
-                         const char *file, const char *anchor,bool separateIndex=FALSE,bool addToNavIndex=FALSE)
-    { foreach<bool,const char *,const char *,const char *,const char*,bool,bool>
-             (&IndexIntf::addContentsItem,isDir,name,ref,file,anchor,separateIndex,addToNavIndex); }
+                         const char *file, const char *anchor,bool separateIndex=FALSE,bool addToNavIndex=FALSE,
+                         Definition *def=0)
+    { if (m_enabled) foreach<bool,const char *,const char *,const char *,const char*,bool,bool,Definition *>
+             (&IndexIntf::addContentsItem,isDir,name,ref,file,anchor,separateIndex,addToNavIndex,def); }
     void addIndexItem(Definition *context,MemberDef *md,const char *title=0)
-    { foreach<Definition *,MemberDef *>
+    { if (m_enabled) foreach<Definition *,MemberDef *>
              (&IndexIntf::addIndexItem,context,md,title); }
     void addIndexFile(const char *name) 
-    { foreach<const char *>(&IndexIntf::addIndexFile,name); }
+    { if (m_enabled) foreach<const char *>(&IndexIntf::addIndexFile,name); }
     void addImageFile(const char *name) 
-    { foreach<const char *>(&IndexIntf::addImageFile,name); }
+    { if (m_enabled) foreach<const char *>(&IndexIntf::addImageFile,name); }
     void addStyleSheetFile(const char *name) 
-    { foreach<const char *>(&IndexIntf::addStyleSheetFile,name); }
+    { if (m_enabled) foreach<const char *>(&IndexIntf::addStyleSheetFile,name); }
 
+  private:
+    bool m_enabled;
 };
 
 
@@ -166,7 +182,7 @@ enum HighlightedItem
   HLI_None=0,
   HLI_Main,
   HLI_Modules,
-  HLI_Directories,
+  //HLI_Directories,
   HLI_Namespaces,
   HLI_Hierarchy,
   HLI_Classes,
@@ -178,6 +194,7 @@ enum HighlightedItem
   HLI_Pages,
   HLI_Examples,
   HLI_Search,
+  HLI_UserGroup,
 
   HLI_ClassVisible,
   HLI_NamespaceVisible,
@@ -257,7 +274,8 @@ void endTitle(OutputList &ol,const char *fileName,const char *name);
 void startFile(OutputList &ol,const char *name,const char *manName,
                const char *title,HighlightedItem hli=HLI_None,
                bool additionalIndices=FALSE,const char *altSidebarName=0);
-void endFile(OutputList &ol,bool skipNavIndex=FALSE,bool skipEndContents=FALSE);
+void endFile(OutputList &ol,bool skipNavIndex=FALSE,bool skipEndContents=FALSE,
+             const QCString &navPath=QCString());
 void endFileWithNavPath(Definition *d,OutputList &ol);
 
 void initClassMemberIndices();
