@@ -3,7 +3,7 @@
  * $Id: layout.cpp,v 1.2 2001/03/19 19:27:41 root Exp $
  *
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -21,6 +21,7 @@
 #include "language.h"
 #include "vhdldocgen.h"
 #include "util.h"
+#include "doxygen.h"
 
 #include <qxml.h>
 #include <qfile.h>
@@ -55,7 +56,8 @@ static bool elemIsVisible(const QXmlAttributes &attrib,bool defVal=TRUE)
 
 //---------------------------------------------------------------------------------
 
-LayoutNavEntry *LayoutNavEntry::find(LayoutNavEntry::Kind kind) const
+LayoutNavEntry *LayoutNavEntry::find(LayoutNavEntry::Kind kind,
+    const char *file) const
 {
   LayoutNavEntry *result=0;
   QListIterator<LayoutNavEntry> li(m_children);
@@ -64,9 +66,9 @@ LayoutNavEntry *LayoutNavEntry::find(LayoutNavEntry::Kind kind) const
   {
     // depth first search, needed to find the entry furthest from the 
     // root in case an entry is in the tree twice
-    result = entry->find(kind);
+    result = entry->find(kind,file);
     if (result) return result;
-    if (entry->kind()==kind)
+    if (entry->kind()==kind && (file==0 || entry->baseFile()==file))
     {
       return entry;
     }
@@ -74,6 +76,39 @@ LayoutNavEntry *LayoutNavEntry::find(LayoutNavEntry::Kind kind) const
   return result;
 }
 
+QCString LayoutNavEntry::url() const
+{
+  QCString url = baseFile().stripWhiteSpace();
+  if (kind()!=LayoutNavEntry::User)
+  {
+    url+=Doxygen::htmlFileExtension;
+  }
+  else if (url.left(5)=="@ref " || url.left(5)=="\\ref ")
+  {
+    Definition *d;
+    QCString anchor;
+    bool found=FALSE;
+    if (resolveLink(0,url.mid(5).stripWhiteSpace(),TRUE,&d,anchor))
+    {
+      if (d && d->isLinkable()) 
+      {
+        url=d->getOutputFileBase()+Doxygen::htmlFileExtension;
+        if (!anchor.isEmpty())
+        {
+          url+="#"+anchor;
+        }
+        found=TRUE;
+      }
+    }
+    if (!found)
+    {
+      msg("warning: explicit link request to '%s' in layout file '%s' could not be resolved\n",qPrint(url.mid(5)),qPrint(Config_getString("LAYOUT_FILE")));
+    }
+  }
+  //printf("LayoutNavEntry::url()=%s\n",url.data());
+  return url;
+}
+
 //---------------------------------------------------------------------------------
 
 class LayoutParser : public QXmlDefaultHandler
@@ -771,13 +806,13 @@ class LayoutParser : public QXmlDefaultHandler
     {
       m_scope="navindex/";
       m_rootNav = LayoutDocManager::instance().rootNavEntry();
-      m_rootNav->clear();
+      if (m_rootNav) m_rootNav->clear();
     }
 
     void endNavIndex()
     {
       m_scope="";
-      if (!m_rootNav->find(LayoutNavEntry::MainPage))
+      if (m_rootNav && !m_rootNav->find(LayoutNavEntry::MainPage))
       {
         // no MainPage node... add one the first item of the root node...
         new LayoutNavEntry(m_rootNav,LayoutNavEntry::MainPage, TRUE, 
@@ -902,13 +937,13 @@ class LayoutParser : public QXmlDefaultHandler
           theTranslator->trFileMembersDescription(extractAll),
           "globals"
         },
-        { "dirs",
-          LayoutNavEntry::Dirs,
-          theTranslator->trDirectories(),
-          QCString(),
-          theTranslator->trDirDescription(),
-          "dirs"
-        },
+        //{ "dirs",
+        //  LayoutNavEntry::Dirs,
+        //  theTranslator->trDirectories(),
+        //  QCString(),
+        //  theTranslator->trDirDescription(),
+        //  "dirs"
+        //},
         { "examples",
           LayoutNavEntry::Examples,
           theTranslator->trExamples(),
@@ -923,6 +958,13 @@ class LayoutParser : public QXmlDefaultHandler
           QCString(),
           "user"
         },
+        { "usergroup",
+          LayoutNavEntry::UserGroup,
+          QCString(),
+          QCString(),
+          QCString(),
+          "usergroup"
+        },
         { 0, // end of list
           (LayoutNavEntry::Kind)0,
           QCString(),
@@ -952,8 +994,9 @@ class LayoutParser : public QXmlDefaultHandler
         }
         else
         {
-          err("error: the type '%s' is not supported for the entry tag within a navindex! Check your layout file!\n");
+          err("error: the type '%s' is not supported for the entry tag within a navindex! Check your layout file!\n",type.data());
         }
+        m_invalidEntry=TRUE;
         return;
       }
       QCString baseFile = mapping[i].baseFile;
@@ -978,6 +1021,10 @@ class LayoutParser : public QXmlDefaultHandler
       {
         baseFile=url;
       }
+      else if (kind==LayoutNavEntry::UserGroup)
+      {
+        baseFile+=QCString().sprintf("%d",m_userGroupCount++);
+      }
       // create new item and make it the new root
       m_rootNav = new LayoutNavEntry(m_rootNav,kind,kind==LayoutNavEntry::MainPage?TRUE:isVisible,baseFile,title,intro);
     }
@@ -985,7 +1032,8 @@ class LayoutParser : public QXmlDefaultHandler
     void endNavEntry()
     {
       // set the root back to the parent
-      m_rootNav = m_rootNav->parent();
+      if (m_rootNav && !m_invalidEntry) m_rootNav = m_rootNav->parent();
+      m_invalidEntry=FALSE;
     }
 
     void startClass(const QXmlAttributes &)
@@ -1106,7 +1154,7 @@ class LayoutParser : public QXmlDefaultHandler
                        const QString& name, const QXmlAttributes& attrib )
     {
       //printf("startElement [%s]::[%s]\n",m_scope.data(),name.data());
-      StartElementHandler *handler = m_sHandler[m_scope+name];
+      StartElementHandler *handler = m_sHandler[m_scope+name.utf8()];
       if (handler)
       {
         (*handler)(attrib);
@@ -1122,13 +1170,13 @@ class LayoutParser : public QXmlDefaultHandler
     {
       //printf("endElement [%s]::[%s]\n",m_scope.data(),name.data());
       EndElementHandler *handler;
-      if (!m_scope.isEmpty() && m_scope.right(name.length()+1)==name+"/")
+      if (!m_scope.isEmpty() && m_scope.right(name.length()+1)==name.utf8()+"/")
       { // element ends current scope
         handler = m_eHandler[m_scope.left(m_scope.length()-1)];
       }
       else // continue with current scope
       {
-        handler = m_eHandler[m_scope+name];
+        handler = m_eHandler[m_scope+name.utf8()];
       }
       if (handler)
       {
@@ -1142,15 +1190,19 @@ class LayoutParser : public QXmlDefaultHandler
     }
 
   private:
-    LayoutParser() : m_sHandler(163), m_eHandler(17) { }
+    LayoutParser() : m_sHandler(163), m_eHandler(17), m_invalidEntry(FALSE) { }
 
     QDict<StartElementHandler> m_sHandler;
     QDict<EndElementHandler>   m_eHandler;
-    QString m_scope;
+    QCString m_scope;
     int m_part;
     LayoutNavEntry *m_rootNav;
+    bool m_invalidEntry;
+    static int m_userGroupCount;
 };
 
+int LayoutParser::m_userGroupCount=0;
+
 //---------------------------------------------------------------------------------
 
 class LayoutErrorHandler : public QXmlErrorHandler
