@@ -3,7 +3,7 @@
  * $Id: $
  *
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -84,6 +84,7 @@ void ManDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Hash:    m_t << "#"; break;
     case DocSymbol::DoubleColon: m_t << "::"; break;
     case DocSymbol::Percent: m_t << "%"; break;
+    case DocSymbol::Pipe:    m_t << "|"; break;
     case DocSymbol::Copy:    m_t << "(C)"; break;
     case DocSymbol::Tm:      m_t << "(TM)"; break;
     case DocSymbol::Reg:     m_t << "(R)"; break;
@@ -106,7 +107,8 @@ void ManDocVisitor::visit(DocSymbol *s)
     case DocSymbol::Ring:    m_t << s->letter() << "\\*o"; break;
     case DocSymbol::Nbsp:    m_t << " "; break;
     default:
-                             err("error: unknown symbol found\n");
+         // unsupport symbol for man page :-(
+         break;
   }
   m_firstCol=FALSE;
 }
@@ -219,6 +221,7 @@ void ManDocVisitor::visit(DocVerbatim *s)
     case DocVerbatim::HtmlOnly: 
     case DocVerbatim::XmlOnly: 
     case DocVerbatim::LatexOnly: 
+    case DocVerbatim::RtfOnly: 
     case DocVerbatim::Dot: 
     case DocVerbatim::Msc: 
       /* nothing */ 
@@ -242,7 +245,7 @@ void ManDocVisitor::visit(DocInclude *inc)
          m_t << ".PP" << endl;
          m_t << ".nf" << endl;
          QFileInfo cfi( inc->file() );
-         FileDef fd( cfi.dirPath(), cfi.fileName() );
+         FileDef fd( cfi.dirPath().utf8(), cfi.fileName().utf8() );
          Doxygen::parserManager->getParser(inc->extension())
                                ->parseCode(m_ci,inc->context(),
                                            inc->text(),
@@ -955,6 +958,27 @@ void ManDocVisitor::visitPost(DocText *)
 {
 }
 
+void ManDocVisitor::visitPre(DocHtmlBlockQuote *)
+{
+  if (m_hide) return;
+  if (!m_firstCol)
+  { 
+    m_t << endl;
+    m_t << ".PP" << endl;
+  }
+  m_t << ".RS 4" << endl; // TODO: add support for nested block quotes
+}
+
+void ManDocVisitor::visitPost(DocHtmlBlockQuote *)
+{
+  if (m_hide) return;
+  if (!m_firstCol) m_t << endl;
+  m_t << ".RE" << endl;
+  m_t << ".PP" << endl;
+  m_firstCol=TRUE;
+}
+
+
 void ManDocVisitor::filter(const char *str)
 { 
   if (str)
