@@ -2,7 +2,7 @@
  *
  * $Id: namespacedef.cpp,v 1.27 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -237,9 +237,12 @@ void NamespaceDef::writeDetailedDescription(OutputList &ol,const QCString &title
       !documentation().isEmpty()
      )
   {
-    ol.writeRuler();
     ol.pushGeneratorState();
-    ol.disableAllBut(OutputGenerator::Html);
+      ol.disable(OutputGenerator::Html);
+      ol.writeRuler();
+    ol.popGeneratorState();
+    ol.pushGeneratorState();
+      ol.disableAllBut(OutputGenerator::Html);
       ol.writeAnchor(0,"details"); 
     ol.popGeneratorState();
     ol.startGroupHeader();
@@ -394,7 +397,8 @@ void NamespaceDef::writeSummaryLinks(OutputList &ol)
     {
       LayoutDocEntrySection *ls = (LayoutDocEntrySection*)lde;
       QCString label = lde->kind()==LayoutDocEntry::NamespaceClasses ? "nested-classes" : "namespaces";
-      writeSummaryLink(ol,label,ls->title,first);
+      ol.writeSummaryLink(0,label,ls->title,first);
+      first=FALSE;
     }
     else if (lde->kind()== LayoutDocEntry::MemberDecl)
     {
@@ -402,7 +406,8 @@ void NamespaceDef::writeSummaryLinks(OutputList &ol)
       MemberList * ml = getMemberList(lmd->type);
       if (ml && ml->declVisible())
       {
-        writeSummaryLink(ol,ml->listTypeAsString(),lmd->title,first);
+        ol.writeSummaryLink(0,ml->listTypeAsString(),lmd->title,first);
+        first=FALSE;
       }
     }
   }
@@ -591,7 +596,7 @@ void NamespaceDef::writeMemberPages(OutputList &ol)
   {
     if (ml->listType()&MemberList::documentationLists)
     {
-      ml->writeDocumentationPage(ol,name(),this);
+      ml->writeDocumentationPage(ol,displayName(),this);
     }
   }
   ol.popGeneratorState();
@@ -739,9 +744,9 @@ void NamespaceDef::addListReferences()
   }
 }
 
-QCString NamespaceDef::displayName() const
+QCString NamespaceDef::displayName(bool includeScope) const
 {
-  QCString result=name();
+  QCString result=includeScope ? name() : localName();
   SrcLangExt lang = getLanguage();
   QCString sep = getLanguageSpecificSeparator(lang);
   if (sep!="::")
@@ -752,6 +757,17 @@ QCString NamespaceDef::displayName() const
   return result; 
 }
 
+QCString NamespaceDef::localName() const
+{
+  QCString result=name();
+  int i=result.findRev("::");
+  if (i!=-1)
+  {
+    result=result.mid(i+2);
+  }
+  return result;
+}
+
 void NamespaceDef::combineUsingRelations()
 {
   if (visited) return; // already done
@@ -836,7 +852,7 @@ void NamespaceSDict::writeDeclaration(OutputList &ol,const char *title,bool loca
     if (nd->isLinkable())
     {
       SrcLangExt lang = nd->getLanguage();
-      ol.startMemberItem(0);
+      ol.startMemberItem(nd->getOutputFileBase(),0);
       if (lang==SrcLangExt_Java || lang==SrcLangExt_CSharp)
       {
         ol.docify("package ");
@@ -867,8 +883,8 @@ void NamespaceSDict::writeDeclaration(OutputList &ol,const char *title,bool loca
       ol.endMemberItem();
       if (!nd->briefDescription().isEmpty() && Config_getBool("BRIEF_MEMBER_DESC"))
       {
-        ol.startMemberDescription();
-        ol.parseDoc(nd->briefFile(),nd->briefLine(),nd,0,nd->briefDescription(),FALSE,FALSE);
+        ol.startMemberDescription(nd->getOutputFileBase());
+        ol.parseDoc(nd->briefFile(),nd->briefLine(),nd,0,nd->briefDescription(),FALSE,FALSE,0,TRUE);
         ol.endMemberDescription();
       }
     }
@@ -950,7 +966,7 @@ void NamespaceDef::writeMemberDeclarations(OutputList &ol,MemberList::ListType l
 void NamespaceDef::writeMemberDocumentation(OutputList &ol,MemberList::ListType lt,const QCString &title)
 {
   MemberList * ml = getMemberList(lt);
-  if (ml) ml->writeDocumentation(ol,name(),this,title);
+  if (ml) ml->writeDocumentation(ol,displayName(),this,title);
 }
 
 
@@ -959,10 +975,9 @@ bool NamespaceDef::isLinkableInProject() const
   int i = name().findRev("::");
   if (i==-1) i=0; else i+=2;
   static bool extractAnonNs = Config_getBool("EXTRACT_ANON_NSPACES");
-  static bool showNamespaces = Config_getBool("SHOW_NAMESPACES");
   if (extractAnonNs &&                             // extract anonymous ns
-      name().mid(i,20)=="anonymous_namespace{" &&  // correct prefix
-      showNamespaces)                              // not disabled by config
+      name().mid(i,20)=="anonymous_namespace{"     // correct prefix
+     )                                             // not disabled by config
   {
     return TRUE;
   }
@@ -970,8 +985,7 @@ bool NamespaceDef::isLinkableInProject() const
     (hasDocumentation() || getLanguage()==SrcLangExt_CSharp) &&  // documented
     !isReference() &&      // not an external reference
     !isHidden() &&         // not hidden
-    !isArtificial() &&     // or artificial
-    showNamespaces;        // not disabled by config
+    !isArtificial();       // or artificial
 }
 
 bool NamespaceDef::isLinkable() const
