@@ -2,7 +2,7 @@
  *
  * $Id: outputlist.h,v 1.47 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -33,6 +33,8 @@
   void forall(void (OutputGenerator::*func)(arg1,arg2,arg3,arg4),arg1,arg2,arg3,arg4)
 #define FORALLPROTO5(arg1,arg2,arg3,arg4,arg5) \
   void forall(void (OutputGenerator::*func)(arg1,arg2,arg3,arg4,arg5),arg1,arg2,arg3,arg4,arg5)
+#define FORALLPROTO6(arg1,arg2,arg3,arg4,arg5,arg6) \
+  void forall(void (OutputGenerator::*func)(arg1,arg2,arg3,arg4,arg5,arg6),arg1,arg2,arg3,arg4,arg5,arg6)
   
 class ClassDiagram;
 class DotClassGraph;
@@ -42,6 +44,9 @@ class DotGfxHierarchyTable;
 class SectionDict;
 class DotGroupCollaboration;
 
+/** Class representing a list of output generators that are written to
+ *  in parallel. 
+ */
 class OutputList : public OutputDocInterface
 {
   public:
@@ -49,6 +54,7 @@ class OutputList : public OutputDocInterface
     virtual ~OutputList();
 
     void add(const OutputGenerator *);
+    uint count() const { return outputs->count(); }
     
     void disableAllBut(OutputGenerator::OutputType o);
     void enableAll();
@@ -87,8 +93,8 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startFile,name,manName,title); }
     void writeSearchInfo()
     { forall(&OutputGenerator::writeSearchInfo); }
-    void writeFooter()
-    { forall(&OutputGenerator::writeFooter); }
+    void writeFooter(const char *navPath)
+    { forall(&OutputGenerator::writeFooter,navPath); }
     void endFile() 
     { forall(&OutputGenerator::endFile); }
     void startTitleHead(const char *fileName) 
@@ -201,14 +207,14 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startAnonTypeScope,i1); }
     void endAnonTypeScope(int i1) 
     { forall(&OutputGenerator::endAnonTypeScope,i1); }
-    void startMemberItem(int i1) 
-    { forall(&OutputGenerator::startMemberItem,i1); }
+    void startMemberItem(const char *anchor,int i1,const char *id=0) 
+    { forall(&OutputGenerator::startMemberItem,anchor,i1,id); }
     void endMemberItem() 
     { forall(&OutputGenerator::endMemberItem); }
     void startMemberTemplateParams() 
     { forall(&OutputGenerator::startMemberTemplateParams); }
-    void endMemberTemplateParams() 
-    { forall(&OutputGenerator::endMemberTemplateParams); }
+    void endMemberTemplateParams(const char *anchor) 
+    { forall(&OutputGenerator::endMemberTemplateParams,anchor); }
     void startMemberGroupHeader(bool b) 
     { forall(&OutputGenerator::startMemberGroupHeader,b); }
     void endMemberGroupHeader()
@@ -231,8 +237,8 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startCodeFragment); }
     void endCodeFragment() 
     { forall(&OutputGenerator::endCodeFragment); }
-    void startCodeLine() 
-    { forall(&OutputGenerator::startCodeLine); }
+    void startCodeLine(bool hasLineNumbers) 
+    { forall(&OutputGenerator::startCodeLine,hasLineNumbers); }
     void endCodeLine() 
     { forall(&OutputGenerator::endCodeLine); }
     void writeLineNumber(const char *ref,const char *file,const char *anchor,
@@ -295,10 +301,15 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startBold); }
     void endBold() 
     { forall(&OutputGenerator::endBold); }
-    void startMemberDescription() 
-    { forall(&OutputGenerator::startMemberDescription); }
+    void startMemberDescription(const char *anchor,const char *inheritId=0) 
+    { forall(&OutputGenerator::startMemberDescription,anchor,inheritId); }
     void endMemberDescription() 
     { forall(&OutputGenerator::endMemberDescription); }
+    void writeInheritedSectionTitle(const char *id,   const char *ref,
+                                    const char *file, const char *anchor,
+                                    const char *title,const char *name)
+    { forall(&OutputGenerator::writeInheritedSectionTitle,id,ref,
+                                    file,anchor,title,name); }
     void startSimpleSect(SectionTypes t,const char *file,const char *anchor,
                          const char *title) 
     { forall(&OutputGenerator::startSimpleSect,t,file,anchor,title); }
@@ -308,8 +319,6 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startParamList,t,title); }
     void endParamList() 
     { forall(&OutputGenerator::endParamList); }
-    //void writeDescItem() 
-    //{ forall(&OutputGenerator::writeDescItem); }
     void startIndent() 
     { forall(&OutputGenerator::startIndent); }
     void endIndent() 
@@ -336,10 +345,14 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::endQuickIndices); }
     void writeSplitBar(const char *name)
     { forall(&OutputGenerator::writeSplitBar,name); }
+    void writeNavigationPath(const char *s)
+    { forall(&OutputGenerator::writeNavigationPath,s); }
     void writeLogo()
     { forall(&OutputGenerator::writeLogo); }
-    void writeQuickLinks(bool compact,HighlightedItem hli)
-    { forall(&OutputGenerator::writeQuickLinks,compact,hli); }
+    void writeQuickLinks(bool compact,HighlightedItem hli,const char *file)
+    { forall(&OutputGenerator::writeQuickLinks,compact,hli,file); }
+    void writeSummaryLink(const char *file,const char *anchor,const char *title,bool first)
+    { forall(&OutputGenerator::writeSummaryLink,file,anchor,title,first); }
     void startContents()
     { forall(&OutputGenerator::startContents); }
     void endContents()
@@ -441,6 +454,13 @@ class OutputList : public OutputDocInterface
     void endInlineMemberDoc()
     { forall(&OutputGenerator::endInlineMemberDoc); }
 
+    void startLabels() 
+    { forall(&OutputGenerator::startLabels); }
+    void writeLabel(const char *l,bool isLast)
+    { forall(&OutputGenerator::writeLabel,l,isLast); }
+    void endLabels()
+    { forall(&OutputGenerator::endLabels); }
+
     void startFontClass(const char *c)
     { forall(&OutputGenerator::startFontClass,c); }
     void endFontClass()
@@ -489,17 +509,19 @@ class OutputList : public OutputDocInterface
     FORALLPROTO1(bool);
     FORALLPROTO2(bool,int);
     FORALLPROTO2(bool,bool);
+    FORALLPROTO2(const char *,bool);
     FORALLPROTO4(const char *,const char *,const char *,int);
 #endif
     FORALLPROTO2(int,bool);
-    FORALLPROTO2(bool,HighlightedItem);
     FORALLPROTO2(bool,const char *);
     FORALLPROTO2(ParamListTypes,const char *);
     FORALLPROTO2(const char *,const char *);
-    FORALLPROTO2(const char *,bool);
+    FORALLPROTO2(const char *,int);
     FORALLPROTO2(const char *,SectionInfo::SectionType);
+    FORALLPROTO3(bool,HighlightedItem,const char *);
     FORALLPROTO3(bool,bool,bool);
     FORALLPROTO3(const char *,const char *,bool);
+    FORALLPROTO3(const char *,int,const char *);
     FORALLPROTO3(const char *,const char *,SectionInfo::SectionType);
     FORALLPROTO3(uchar,uchar,uchar);
     FORALLPROTO3(const char *,const char *,const char *);
@@ -509,6 +531,7 @@ class OutputList : public OutputDocInterface
     FORALLPROTO4(const char *,const char *,const char *,bool);
     FORALLPROTO5(const char *,const char *,const char *,const char *,const char *);
     FORALLPROTO5(const char *,const char *,const char *,const char *,bool);
+    FORALLPROTO6(const char *,const char *,const char *,const char *,const char *,const char *);
   
     OutputList(const OutputList &ol);
     QList<OutputGenerator> *outputs;
