@@ -17,6 +17,7 @@ PageDef::PageDef(const char *f,int l,const char *n,
   m_subPageDict = new PageSDict(7);
   m_pageScope = 0;
   m_nestingLevel = 0;
+  m_showToc = FALSE;
 }
 
 PageDef::~PageDef()
@@ -77,8 +78,6 @@ void PageDef::writeDocumentation(OutputList &ol)
 
   //printf("PageDef::writeDocumentation: %s\n",getOutputFileBase().data());
 
-  startFile(ol,getOutputFileBase(),pageName,title(),HLI_Pages,!generateTreeView);
-
   ol.pushGeneratorState();
   //1.{ 
 
@@ -94,11 +93,13 @@ void PageDef::writeDocumentation(OutputList &ol)
     ol.enable(OutputGenerator::Html);
   }
 
+  startFile(ol,getOutputFileBase(),pageName,title(),HLI_Pages,!generateTreeView);
+
   if (!generateTreeView)
   {
     if (getOuterScope()!=Doxygen::globalScope && !Config_getBool("DISABLE_INDEX"))
     {
-      getOuterScope()->writeNavigationPath(ol,FALSE);
+      getOuterScope()->writeNavigationPath(ol);
     }
     ol.endQuickIndices();
   }
@@ -139,10 +140,12 @@ void PageDef::writeDocumentation(OutputList &ol)
   ol.popGeneratorState();
   //2.}
 
-  writePageDocumentation(ol);
+  if (m_showToc && hasSections())
+  {
+    writeToc(ol);
+  }
 
-  ol.popGeneratorState();
-  //1.}
+  writePageDocumentation(ol);
 
   if (generateTreeView && getOuterScope()!=Doxygen::globalScope && !Config_getBool("DISABLE_INDEX"))
   {
@@ -154,6 +157,9 @@ void PageDef::writeDocumentation(OutputList &ol)
     endFile(ol);
   }
 
+  ol.popGeneratorState();
+  //1.}
+
   if (!Config_getString("GENERATE_TAGFILE").isEmpty())
   {
     bool found=FALSE;
@@ -183,6 +189,13 @@ void PageDef::writeDocumentation(OutputList &ol)
 
 void PageDef::writePageDocumentation(OutputList &ol)
 {
+
+  bool markdownEnabled = Doxygen::markdownSupport;
+  if (getLanguage()==SrcLangExt_Markdown)
+  {
+    Doxygen::markdownSupport = TRUE;
+  }
+
   ol.startTextBlock();
   ol.parseDoc(
       docFile(),           // fileName
@@ -195,6 +208,8 @@ void PageDef::writePageDocumentation(OutputList &ol)
       );
   ol.endTextBlock();
 
+  Doxygen::markdownSupport = markdownEnabled;
+
   if (hasSubPages())
   {
     // for printed documentation we write subpages as section's of the
@@ -233,14 +248,17 @@ void PageDef::writePageDocumentation(OutputList &ol)
 
 bool PageDef::visibleInIndex() const
 {
-   return // not part of a group
-          !getGroupDef() && 
-          // not an externally defined page
-          (!isReference() || Config_getBool("ALLEXTERNALS")) &&
-          // not a subpage
-          (getOuterScope()==0 || 
-           getOuterScope()->definitionType()!=Definition::TypePage
-          );
+  static bool allExternals = Config_getBool("ALLEXTERNALS");
+  return // not part of a group
+         !getGroupDef() && 
+         // not an externally defined page
+         (!isReference() || allExternals) 
+         // &&
+         // not a subpage
+         //(getOuterScope()==0 || 
+         // getOuterScope()->definitionType()!=Definition::TypePage
+         //)
+         ;
 }
 
 bool PageDef::documentedPage() const
@@ -261,3 +279,8 @@ void PageDef::setNestingLevel(int l)
   m_nestingLevel = l;
 }
 
+void PageDef::setShowToc(bool b)
+{
+  m_showToc = b;
+}
+
