@@ -1,5 +1,5 @@
 /******************************************************************************
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -34,7 +34,7 @@
 #ifndef TRANSLATOR_BR_H
 #define TRANSLATOR_BR_H
 
-class TranslatorBrazilian : public Translator
+class TranslatorBrazilian : public TranslatorAdapter_1_8_0
 {
   public:
 
@@ -113,7 +113,7 @@ class TranslatorBrazilian : public Translator
 
     /*! put in the class documentation */
     virtual QCString trListOfAllMembers()
-    { return "Lista de todos os Membros."; }
+    { return "Lista de todos os Membros"; }
 
     /*! used as the title of the "list of all members" page of a class */
     virtual QCString trMemberList()
