@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -40,7 +40,7 @@
  Translator class (by the local maintainer) when the localized
  translator is made up-to-date again.
 */
-class TranslatorCatalan : public Translator
+class TranslatorCatalan : public TranslatorAdapter_1_8_0
 {
   public:
 
@@ -126,7 +126,7 @@ class TranslatorCatalan : public Translator
 
     /*! put in the class documentation */
     virtual QCString trListOfAllMembers()
-    { return "Llista de tots els membres."; }
+    { return "Llista de tots els membres"; }
 
     /*! used as the title of the "list of all members" page of a class */
     virtual QCString trMemberList()
