@@ -3,7 +3,7 @@
  *
  *
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -87,7 +87,7 @@
 #ifndef TRANSLATOR_DK_H
 #define TRANSLATOR_DK_H
 
-class TranslatorDanish : public Translator
+class TranslatorDanish : public TranslatorAdapter_1_8_0
 {
   public:
 
@@ -170,7 +170,7 @@ class TranslatorDanish : public Translator
 
     /*! put in the class documentation */
     virtual QCString trListOfAllMembers()
-    { return "Liste over alle medlemmer."; }
+    { return "Liste over alle medlemmer"; }
 
     /*! used as the title of the "list of all members" page of a class */
     virtual QCString trMemberList()
