@@ -2,7 +2,7 @@
  *
  *
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -26,7 +26,7 @@
 #ifndef TRANSLATOR_GR_H
 #define TRANSLATOR_GR_H
 
-class TranslatorGreek : public Translator
+class TranslatorGreek : public TranslatorAdapter_1_8_0
 {
   protected:
     friend class TranslatorAdapterBase;
@@ -101,7 +101,7 @@ class TranslatorGreek : public Translator
 
     /*! put in the class documentation */
     virtual QCString trListOfAllMembers()
-    { return "Λίστα όλων των μελών."; }
+    { return "Λίστα όλων των μελών"; }
 
     /*! used as the title of the "list of all members" page of a class */
     virtual QCString trMemberList()
