@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2007 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,13 +18,13 @@
 #ifndef TRANSLATOR_ID_H
 #define TRANSLATOR_ID_H
 
-/** 
+/* 
  * Translasi berikut didasarkan pada versi translator_en.h dalam
  * Doxygen 1.7.5.1.
  *
  * Penterjemah: Adhi Hargo <cadmus_sw at yahoo.com>
  */
-class TranslatorIndonesian : public Translator
+class TranslatorIndonesian : public TranslatorAdapter_1_8_0
 {
   public:
 
@@ -109,7 +109,7 @@ class TranslatorIndonesian : public Translator
 
     /*! put in the class documentation */
     virtual QCString trListOfAllMembers()
-    { return "Daftar semua anggota."; }
+    { return "Daftar semua anggota"; }
 
     /*! used as the title of the "list of all members" page of a class */
     virtual QCString trMemberList()
