@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -118,7 +118,7 @@ class TranslatorLithuanian : public TranslatorAdapter_1_4_6
 
     /*! put in the class documentation */
     virtual QCString trListOfAllMembers()
-    { return "Vis nari sraas."; }
+    { return "Vis nari sraas"; }
 
     /*! used as the title of the "list of all members" page of a class */
     virtual QCString trMemberList()
