@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2008 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -113,7 +113,7 @@ class TranslatorAfrikaans : public TranslatorAdapter_1_6_0
 
     /*! put in the class documentation */
     virtual QCString trListOfAllMembers()
-    { return "Lys van alle lede."; }
+    { return "Lys van alle lede"; }
 
     /*! used as the title of the "list of all members" page of a class */
     virtual QCString trMemberList()
