@@ -2,7 +2,7 @@
  *
  * $Id: util.h,v 1.49 2001/03/19 19:27:42 root Exp $
  *
- * Copyright (C) 1997-2011 by Dimitri van Heesch.
+ * Copyright (C) 1997-2012 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -18,7 +18,7 @@
 #ifndef UTIL_H
 #define UTIL_H
 
-/*! \file util.h 
+/*! \file 
  *  \brief A bunch of utility functions.
  */
 
@@ -27,6 +27,7 @@
 #include <qtextstream.h>
 #include <ctype.h>
 #include "sortdict.h"
+#include "types.h"
 
 //--------------------------------------------------------------------
 
@@ -60,6 +61,7 @@ class FTextStream;
 
 //--------------------------------------------------------------------
 
+/** Abstract interface for a hyperlinked text fragment. */
 class TextGeneratorIntf
 {
   public:
@@ -71,6 +73,7 @@ class TextGeneratorIntf
                      ) const = 0; 
 };
 
+/** Implements TextGeneratorIntf for an OutputDocInterface stream. */
 class TextGeneratorOLImpl : public TextGeneratorIntf
 {
   public:
@@ -87,33 +90,15 @@ class TextGeneratorOLImpl : public TextGeneratorIntf
 
 //--------------------------------------------------------------------
 
-enum SrcLangExt
-{
-  SrcLangExt_Unknown = 0x0000,
-  SrcLangExt_IDL     = 0x0008,
-  SrcLangExt_Java    = 0x0010,
-  SrcLangExt_CSharp  = 0x0020,
-  SrcLangExt_D       = 0x0040,
-  SrcLangExt_PHP     = 0x0080,
-  SrcLangExt_ObjC    = 0x0100,
-  SrcLangExt_Cpp     = 0x0200,
-  SrcLangExt_JS      = 0x0400,
-  SrcLangExt_Python  = 0x0800,
-  SrcLangExt_Fortran = 0x1000,
-  SrcLangExt_VHDL    = 0x2000,
-  SrcLangExt_XML     = 0x4000,
-  SrcLangExt_Tcl     = 0x8000
-};
-
 QCString langToString(SrcLangExt lang);
-QCString getLanguageSpecificSeparator(SrcLangExt lang);
+QCString getLanguageSpecificSeparator(SrcLangExt lang,bool classScope=FALSE);
 
 //--------------------------------------------------------------------
 
 void linkifyText(const TextGeneratorIntf &ol,
                  Definition *scope,
                  FileDef *fileScope,
-                 const char *name,
+                 Definition *self,
                  const char *text,
                  bool autoBreak=FALSE,
                  bool external=TRUE,
@@ -137,7 +122,8 @@ bool getDefs(const QCString &scopeName,
                     GroupDef *&gd,
                     bool forceEmptyScope=FALSE,
                     FileDef *currentFile=0,
-                    bool checkCV=FALSE
+                    bool checkCV=FALSE,
+                    const char *forceTagFile=0
                    );
 
 QCString getFileFilter(const char* name,bool isSourceCode);
@@ -248,6 +234,7 @@ void initClassHierarchy(ClassSDict *cl);
 bool hasVisibleRoot(BaseClassList *bcl);
 
 int minClassDistance(const ClassDef *cd,const ClassDef *bcd,int level=0);
+Protection classInheritedProtectionLevel(ClassDef *cd,ClassDef *bcd,Protection prot=Public,int level=0);
 
 QCString convertNameToFile(const char *name,bool allowDots=FALSE,bool allowUnderscore=FALSE);
 
@@ -305,7 +292,8 @@ PageDef *addRelatedPage(const char *name,const QCString &ptitle,
                            const char *fileName,int startLine,
                            const QList<ListItemInfo> *sli,
                            GroupDef *gd=0,
-                           TagInfo *tagInfo=0
+                           TagInfo *tagInfo=0,
+                           SrcLangExt lang=SrcLangExt_Unknown
                           );
 
 QCString escapeCharsInString(const char *name,bool allowDots,bool allowUnderscore=FALSE);
@@ -344,7 +332,7 @@ bool containsWord(const QCString &s,const QCString &word);
 
 bool findAndRemoveWord(QCString &s,const QCString &word);
 
-QCString stripLeadingAndTrailingEmptyLines(const QCString &s);
+QCString stripLeadingAndTrailingEmptyLines(const QCString &s,int &docLine);
 
 //void stringToSearchIndex(const QCString &docUrlBase,const QCString &title,
 //                         const QCString &str, bool priority=FALSE,
@@ -382,7 +370,6 @@ void writeTypeConstraints(OutputList &ol,Definition *d,ArgumentList *al);
 
 QCString convertCharEntitiesToUTF8(const QCString &s);
 
-bool usingTreeIndex();
 void stackTrace();
 
 bool readInputFile(const char *fileName,BufStr &inBuf);
@@ -390,13 +377,11 @@ QCString filterTitle(const QCString &title);
 
 bool patternMatch(const QFileInfo &fi,const QStrList *patList);
 
-void writeSummaryLink(OutputList &ol,const char *label,const char *title,
-                      bool &first);
-
 QCString externalLinkTarget();
 QCString externalRef(const QCString &relPath,const QCString &ref,bool href);
 int nextUtf8CharPosition(const QCString &utf8Str,int len,int startPos);
 
+/** Data associated with a HSV colored image. */
 struct ColoredImgDataItem
 {
   const char *name;
@@ -412,5 +397,15 @@ QCString replaceColorMarkers(const char *str);
 bool copyFile(const QCString &src,const QCString &dest);
 QCString extractBlock(const QCString text,const QCString marker);
 
+QCString correctURL(const QCString &url,const QCString &relPath);
+
+QCString processMarkup(const QCString &s);
+
+bool protectionLevelVisible(Protection prot);
+
+QCString stripIndentation(const QCString &s);
+
+bool fileVisibleInIndex(FileDef *fd,bool &genSourceFile);
+
 #endif
 
